import io

import pandas as pd


@pd.api.extensions.register_dataframe_accessor("histogram")
@pd.api.extensions.register_series_accessor("histogram")
class Histogram:
    def __init__(self, pandas_obj):
        self._validate(pandas_obj)
        self._obj = pandas_obj

    @staticmethod
    def _validate(obj):
        pass

    def plot(self, autoopen=True):
        """Plot opens the dataframe in histogram.dev"""
        import requests

        from . import base_url

        buf = io.BytesIO()
        self._obj.to_csv(buf, index=False)
        buf.seek(0)

        rawResp = requests.post(f"{base_url}/datafiles/hold", data=buf, headers={"Content-Type": "text/csv"})
        if rawResp.status_code != 200:
            raise Exception(rawResp.text)

        resp = rawResp.json()

        if autoopen:
            import webbrowser
            webbrowser.open(resp["urls"]["ui"])

        return resp



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['histogram']

package_data = \
{'': ['*']}

install_requires = \
['pandas>=1.0,<2.0', 'requests>=2.0,<3.0']

setup_kwargs = {
    'name': 'histogram-py',
    'version': '0.1.2',
    'description': 'A pandas extension to open Dataframes & Series in histogram.dev',
    'long_description': '# Histogram\n\nA pandas extension to open Dataframes & Series in [histogram.dev](https://histogram.dev).\n\n\n## Usage/Examples\n\n```python\nimport histogram # Import at least once, anywhere\n\ndf.histogram.plot()\n\n```\n\n',
    'author': 'Tyler Cosgrove',
    'author_email': 'tyler@datawhys.ai',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://histogram.dev',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)
